;; Generated package description from substitute.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "substitute" "0.6.0.0.20260728.2" "Efficiently replace targets in the buffer or context" '((emacs "27.1")) :commit "4e225914857725b7b5f32d6705773554ff27409e" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :url "https://github.com/protesilaos/substitute")
